---
title: Guide to Anonymising data
prefix: Tip
...

We anonymize data to mask confidential information, but preserving the insights that emerge from the data.

The wiki has a [guide to anonymising data](https://learn.gramener.com/wiki/anonymisation.html#).
It's a simple process that we should follow when anonymising client data or any
other sensitive data, while still preserving the key elements of insights.
